/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.mgmt;

public class DriverParameter extends com.mysql.grt.GrtObject {

    protected DriverParameter() {
    }

    public DriverParameter(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new DriverParameterDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new DriverParameterDataGlobal((String) obj);
        }
    }

    public int getRequired() {
        return ((DriverParameterData) data).getRequired();
    }

    public int setRequired(int required) {
        ((DriverParameterData) data).setRequired(required);

        return getRequired();
    }

    public int getLayoutAdvanced() {
        return ((DriverParameterData) data).getLayoutAdvanced();
    }

    public int setLayoutAdvanced(int layoutAdvanced) {
        ((DriverParameterData) data).setLayoutAdvanced(layoutAdvanced);

        return getLayoutAdvanced();
    }

    public int getLayoutRow() {
        return ((DriverParameterData) data).getLayoutRow();
    }

    public int setLayoutRow(int layoutRow) {
        ((DriverParameterData) data).setLayoutRow(layoutRow);

        return getLayoutRow();
    }

    public int getLayoutWidth() {
        return ((DriverParameterData) data).getLayoutWidth();
    }

    public int setLayoutWidth(int layoutWidth) {
        ((DriverParameterData) data).setLayoutWidth(layoutWidth);

        return getLayoutWidth();
    }

    public String getCaption() {
        return ((DriverParameterData) data).getCaption();
    }

    public String setCaption(String caption) {
        ((DriverParameterData) data).setCaption(caption);

        return getCaption();
    }

    public String getDescription() {
        return ((DriverParameterData) data).getDescription();
    }

    public String setDescription(String description) {
        ((DriverParameterData) data).setDescription(description);

        return getDescription();
    }

    public String getParamType() {
        return ((DriverParameterData) data).getParamType();
    }

    public String setParamType(String paramType) {
        ((DriverParameterData) data).setParamType(paramType);

        return getParamType();
    }

    public String getDefaultValue() {
        return ((DriverParameterData) data).getDefaultValue();
    }

    public String setDefaultValue(String defaultValue) {
        ((DriverParameterData) data).setDefaultValue(defaultValue);

        return getDefaultValue();
    }

    public String getLookupValueModule() {
        return ((DriverParameterData) data).getLookupValueModule();
    }

    public String setLookupValueModule(String lookupValueModule) {
        ((DriverParameterData) data).setLookupValueModule(lookupValueModule);

        return getLookupValueModule();
    }

    public String getLookupValueMethod() {
        return ((DriverParameterData) data).getLookupValueMethod();
    }

    public String setLookupValueMethod(String lookupValueMethod) {
        ((DriverParameterData) data).setLookupValueMethod(lookupValueMethod);

        return getLookupValueMethod();
    }

    public com.mysql.grt.GrtStringHashMap getParamTypeDetails() {
        return ((DriverParameterData) data).getParamTypeDetails();
    }

    public com.mysql.grt.GrtStringHashMap setParamTypeDetails(com.mysql.grt.GrtStringHashMap paramTypeDetails) {
        ((DriverParameterData) data).setParamTypeDetails(paramTypeDetails);

        return getParamTypeDetails();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"required\">"
                    + Integer.toString(getRequired()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"layoutAdvanced\">"
                    + Integer.toString(getLayoutAdvanced()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"layoutRow\">"
                    + Integer.toString(getLayoutRow()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"layoutWidth\">"
                    + Integer.toString(getLayoutWidth()) + "</value>\n");

            if (getCaption() != null) {
                xml.append("<value type=\"string\" key=\"caption\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getCaption()) + "</value>\n");
            }

            if (getDescription() != null) {
                xml.append("<value type=\"string\" key=\"description\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDescription()) + "</value>\n");
            }

            if (getParamType() != null) {
                xml.append("<value type=\"string\" key=\"paramType\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getParamType()) + "</value>\n");
            }

            if (getDefaultValue() != null) {
                xml.append("<value type=\"string\" key=\"defaultValue\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDefaultValue()) + "</value>\n");
            }

            if (getLookupValueModule() != null) {
                xml.append("<value type=\"string\" key=\"lookupValueModule\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getLookupValueModule()) + "</value>\n");
            }

            if (getLookupValueMethod() != null) {
                xml.append("<value type=\"string\" key=\"lookupValueMethod\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getLookupValueMethod()) + "</value>\n");
            }

            if (getParamTypeDetails() != null) {
                getParamTypeDetails().getGrtXml(xml, " key=\"paramTypeDetails\"");
            }

        return xml;
    }
}
