/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.mysql;

public class Routine extends com.mysql.grt.db.Routine {

    protected Routine() {
    }

    public Routine(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new RoutineDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new RoutineDataGlobal((String) obj);
        }
    }

    public String getSecurity() {
        return ((RoutineData) data).getSecurity();
    }

    public String setSecurity(String security) {
        ((RoutineData) data).setSecurity(security);

        return getSecurity();
    }

    public String getReturnDatatype() {
        return ((RoutineData) data).getReturnDatatype();
    }

    public String setReturnDatatype(String returnDatatype) {
        ((RoutineData) data).setReturnDatatype(returnDatatype);

        return getReturnDatatype();
    }

    public com.mysql.grt.db.mysql.RoutineParamList getParams() {
        return ((RoutineData) data).getParams();
    }

    public com.mysql.grt.db.mysql.RoutineParamList setParams(com.mysql.grt.db.mysql.RoutineParamList params) {
        ((RoutineData) data).setParams(params);

        return getParams();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            if (getSecurity() != null) {
                xml.append("<value type=\"string\" key=\"security\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getSecurity()) + "</value>\n");
            }

            if (getReturnDatatype() != null) {
                xml.append("<value type=\"string\" key=\"returnDatatype\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getReturnDatatype()) + "</value>\n");
            }

            if (getParams() != null) {
                getParams().getGrtXml(xml, " key=\"params\"");
            }

        return xml;
    }
}
