/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.mysql;

public class StorageEngine extends com.mysql.grt.base.NamedGrtObject {

    protected StorageEngine() {
    }

    public StorageEngine(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new StorageEngineDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new StorageEngineDataGlobal((String) obj);
        }
    }

    public int getSupportsForeignKeys() {
        return ((StorageEngineData) data).getSupportsForeignKeys();
    }

    public int setSupportsForeignKeys(int supportsForeignKeys) {
        ((StorageEngineData) data).setSupportsForeignKeys(supportsForeignKeys);

        return getSupportsForeignKeys();
    }

    public String getCaption() {
        return ((StorageEngineData) data).getCaption();
    }

    public String setCaption(String caption) {
        ((StorageEngineData) data).setCaption(caption);

        return getCaption();
    }

    public String getDescription() {
        return ((StorageEngineData) data).getDescription();
    }

    public String setDescription(String description) {
        ((StorageEngineData) data).setDescription(description);

        return getDescription();
    }

    public com.mysql.grt.db.mysql.StorageEngineOptionList getOptions() {
        return ((StorageEngineData) data).getOptions();
    }

    public com.mysql.grt.db.mysql.StorageEngineOptionList setOptions(com.mysql.grt.db.mysql.StorageEngineOptionList options) {
        ((StorageEngineData) data).setOptions(options);

        return getOptions();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"supportsForeignKeys\">"
                    + Integer.toString(getSupportsForeignKeys()) + "</value>\n");

            if (getCaption() != null) {
                xml.append("<value type=\"string\" key=\"caption\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getCaption()) + "</value>\n");
            }

            if (getDescription() != null) {
                xml.append("<value type=\"string\" key=\"description\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDescription()) + "</value>\n");
            }

            if (getOptions() != null) {
                getOptions().getGrtXml(xml, " key=\"options\"");
            }

        return xml;
    }
}
