/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.query;

public class Resultset extends com.mysql.grt.GrtObject {

    protected Resultset() {
    }

    public Resultset(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new ResultsetDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new ResultsetDataGlobal((String) obj);
        }
    }

    public int getRowBlockSize() {
        return ((ResultsetData) data).getRowBlockSize();
    }

    public int setRowBlockSize(int rowBlockSize) {
        ((ResultsetData) data).setRowBlockSize(rowBlockSize);

        return getRowBlockSize();
    }

    public int getNextBlockStartRow() {
        return ((ResultsetData) data).getNextBlockStartRow();
    }

    public int setNextBlockStartRow(int nextBlockStartRow) {
        ((ResultsetData) data).setNextBlockStartRow(nextBlockStartRow);

        return getNextBlockStartRow();
    }

    public String getSql() {
        return ((ResultsetData) data).getSql();
    }

    public String setSql(String sql) {
        ((ResultsetData) data).setSql(sql);

        return getSql();
    }

    public com.mysql.grt.db.query.ResultsetColumnList getColumns() {
        return ((ResultsetData) data).getColumns();
    }

    public com.mysql.grt.db.query.ResultsetColumnList setColumns(com.mysql.grt.db.query.ResultsetColumnList columns) {
        ((ResultsetData) data).setColumns(columns);

        return getColumns();
    }

    public com.mysql.grt.db.mgmt.Connection getConnection() {
        return ((ResultsetData) data).getConnection();
    }

    public com.mysql.grt.db.mgmt.Connection setConnection(com.mysql.grt.db.mgmt.Connection connection) {
        ((ResultsetData) data).setConnection(connection);

        return getConnection();
    }

    public String getConnectionById() {
        return ((ResultsetData) data).getConnectionById();
    }

    public void setConnectionById(String connection) {
        ((ResultsetData) data).setConnectionById(connection);
    }

    public com.mysql.grt.db.query.Query getQuery() {
        return ((ResultsetData) data).getQuery();
    }

    public com.mysql.grt.db.query.Query setQuery(com.mysql.grt.db.query.Query query) {
        ((ResultsetData) data).setQuery(query);

        return getQuery();
    }

    public String getQueryById() {
        return ((ResultsetData) data).getQueryById();
    }

    public void setQueryById(String query) {
        ((ResultsetData) data).setQueryById(query);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"rowBlockSize\">"
                    + Integer.toString(getRowBlockSize()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"nextBlockStartRow\">"
                    + Integer.toString(getNextBlockStartRow()) + "</value>\n");

            if (getSql() != null) {
                xml.append("<value type=\"string\" key=\"sql\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getSql()) + "</value>\n");
            }

            if (getColumns() != null) {
                getColumns().getGrtXml(xml, " key=\"columns\"");
            }

            if (getConnection() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"connection\">"
                        + getConnectionById() + "</value>\n");
            }

            if (getQuery() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"query\">"
                        + getQueryById() + "</value>\n");
            }

        return xml;
    }
}
