/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.model;

public class Layer extends com.mysql.grt.GrtObject {

    protected Layer() {
    }

    public Layer(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new LayerDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new LayerDataGlobal((String) obj);
        }
    }

    public int getEnabled() {
        return ((LayerData) data).getEnabled();
    }

    public int setEnabled(int enabled) {
        ((LayerData) data).setEnabled(enabled);

        return getEnabled();
    }

    public int getVisible() {
        return ((LayerData) data).getVisible();
    }

    public int setVisible(int visible) {
        ((LayerData) data).setVisible(visible);

        return getVisible();
    }

    public double getLeft() {
        return ((LayerData) data).getLeft();
    }

    public double setLeft(double left) {
        ((LayerData) data).setLeft(left);

        return getLeft();
    }

    public double getTop() {
        return ((LayerData) data).getTop();
    }

    public double setTop(double top) {
        ((LayerData) data).setTop(top);

        return getTop();
    }

    public double getWidth() {
        return ((LayerData) data).getWidth();
    }

    public double setWidth(double width) {
        ((LayerData) data).setWidth(width);

        return getWidth();
    }

    public double getHeight() {
        return ((LayerData) data).getHeight();
    }

    public double setHeight(double height) {
        ((LayerData) data).setHeight(height);

        return getHeight();
    }

    public String getDescription() {
        return ((LayerData) data).getDescription();
    }

    public String setDescription(String description) {
        ((LayerData) data).setDescription(description);

        return getDescription();
    }

    public com.mysql.grt.model.GroupList getGroups() {
        return ((LayerData) data).getGroups();
    }

    public com.mysql.grt.model.GroupList setGroups(com.mysql.grt.model.GroupList groups) {
        ((LayerData) data).setGroups(groups);

        return getGroups();
    }

    public com.mysql.grt.model.LayerList getSubLayers() {
        return ((LayerData) data).getSubLayers();
    }

    public com.mysql.grt.model.LayerList setSubLayers(com.mysql.grt.model.LayerList subLayers) {
        ((LayerData) data).setSubLayers(subLayers);

        return getSubLayers();
    }

    public com.mysql.grt.model.ElementList getElements() {
        return ((LayerData) data).getElements();
    }

    public com.mysql.grt.model.ElementList setElements(com.mysql.grt.model.ElementList elements) {
        ((LayerData) data).setElements(elements);

        return getElements();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"enabled\">"
                    + Integer.toString(getEnabled()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"visible\">"
                    + Integer.toString(getVisible()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"left\">"
                    + Double.toString(getLeft()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"top\">"
                    + Double.toString(getTop()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"width\">"
                    + Double.toString(getWidth()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"height\">"
                    + Double.toString(getHeight()) + "</value>\n");

            if (getDescription() != null) {
                xml.append("<value type=\"string\" key=\"description\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDescription()) + "</value>\n");
            }

            if (getGroups() != null) {
                getGroups().getGrtXml(xml, " key=\"groups\"");
            }

            if (getSubLayers() != null) {
                getSubLayers().getGrtRefXml(xml, " key=\"subLayers\"");
            }

            if (getElements() != null) {
                getElements().getGrtRefXml(xml, " key=\"elements\"");
            }

        return xml;
    }
}
