/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.model;

public class Model extends com.mysql.grt.GrtObject {

    protected Model() {
    }

    public Model(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new ModelDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new ModelDataGlobal((String) obj);
        }
    }

    public com.mysql.grt.GrtHashMap getCustomData() {
        return ((ModelData) data).getCustomData();
    }

    public com.mysql.grt.GrtHashMap setCustomData(com.mysql.grt.GrtHashMap customData) {
        ((ModelData) data).setCustomData(customData);

        return getCustomData();
    }

    public com.mysql.grt.model.ViewList getViews() {
        return ((ModelData) data).getViews();
    }

    public com.mysql.grt.model.ViewList setViews(com.mysql.grt.model.ViewList views) {
        ((ModelData) data).setViews(views);

        return getViews();
    }

    public com.mysql.grt.model.MarkerList getMarkers() {
        return ((ModelData) data).getMarkers();
    }

    public com.mysql.grt.model.MarkerList setMarkers(com.mysql.grt.model.MarkerList markers) {
        ((ModelData) data).setMarkers(markers);

        return getMarkers();
    }

    public com.mysql.grt.model.View getCurrentView() {
        return ((ModelData) data).getCurrentView();
    }

    public com.mysql.grt.model.View setCurrentView(com.mysql.grt.model.View currentView) {
        ((ModelData) data).setCurrentView(currentView);

        return getCurrentView();
    }

    public String getCurrentViewById() {
        return ((ModelData) data).getCurrentViewById();
    }

    public void setCurrentViewById(String currentView) {
        ((ModelData) data).setCurrentViewById(currentView);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            if (getViews() != null) {
                getViews().getGrtXml(xml, " key=\"views\"");
            }

            if (getMarkers() != null) {
                getMarkers().getGrtXml(xml, " key=\"markers\"");
            }

            if (getCustomData() != null) {
                getCustomData().getGrtXml(xml, " key=\"customData\"");
            }

            if (getCurrentView() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"currentView\">"
                        + getCurrentViewById() + "</value>\n");
            }

        return xml;
    }
}
