/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.model;

public class View extends com.mysql.grt.GrtObject {

    protected View() {
    }

    public View(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new ViewDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new ViewDataGlobal((String) obj);
        }
    }

    public double getZoom() {
        return ((ViewData) data).getZoom();
    }

    public double setZoom(double zoom) {
        ((ViewData) data).setZoom(zoom);

        return getZoom();
    }

    public double getX() {
        return ((ViewData) data).getX();
    }

    public double setX(double x) {
        ((ViewData) data).setX(x);

        return getX();
    }

    public double getY() {
        return ((ViewData) data).getY();
    }

    public double setY(double y) {
        ((ViewData) data).setY(y);

        return getY();
    }

    public double getWidth() {
        return ((ViewData) data).getWidth();
    }

    public double setWidth(double width) {
        ((ViewData) data).setWidth(width);

        return getWidth();
    }

    public double getHeight() {
        return ((ViewData) data).getHeight();
    }

    public double setHeight(double height) {
        ((ViewData) data).setHeight(height);

        return getHeight();
    }

    public String getDescription() {
        return ((ViewData) data).getDescription();
    }

    public String setDescription(String description) {
        ((ViewData) data).setDescription(description);

        return getDescription();
    }

    public String getElementLayoutClass() {
        return ((ViewData) data).getElementLayoutClass();
    }

    public String setElementLayoutClass(String elementLayoutClass) {
        ((ViewData) data).setElementLayoutClass(elementLayoutClass);

        return getElementLayoutClass();
    }

    public String getConnectionLayoutClass() {
        return ((ViewData) data).getConnectionLayoutClass();
    }

    public String setConnectionLayoutClass(String connectionLayoutClass) {
        ((ViewData) data).setConnectionLayoutClass(connectionLayoutClass);

        return getConnectionLayoutClass();
    }

    public com.mysql.grt.model.ElementList getElements() {
        return ((ViewData) data).getElements();
    }

    public com.mysql.grt.model.ElementList setElements(com.mysql.grt.model.ElementList elements) {
        ((ViewData) data).setElements(elements);

        return getElements();
    }

    public com.mysql.grt.model.LayerList getLayers() {
        return ((ViewData) data).getLayers();
    }

    public com.mysql.grt.model.LayerList setLayers(com.mysql.grt.model.LayerList layers) {
        ((ViewData) data).setLayers(layers);

        return getLayers();
    }

    public com.mysql.grt.model.ElementList getSelection() {
        return ((ViewData) data).getSelection();
    }

    public com.mysql.grt.model.ElementList setSelection(com.mysql.grt.model.ElementList selection) {
        ((ViewData) data).setSelection(selection);

        return getSelection();
    }

    public com.mysql.grt.model.Layer getRootLayer() {
        return ((ViewData) data).getRootLayer();
    }

    public com.mysql.grt.model.Layer setRootLayer(com.mysql.grt.model.Layer rootLayer) {
        ((ViewData) data).setRootLayer(rootLayer);

        return getRootLayer();
    }

    public String getRootLayerById() {
        return ((ViewData) data).getRootLayerById();
    }

    public void setRootLayerById(String rootLayer) {
        ((ViewData) data).setRootLayerById(rootLayer);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"real\" key=\"zoom\">"
                    + Double.toString(getZoom()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"x\">"
                    + Double.toString(getX()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"y\">"
                    + Double.toString(getY()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"width\">"
                    + Double.toString(getWidth()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"height\">"
                    + Double.toString(getHeight()) + "</value>\n");

            if (getDescription() != null) {
                xml.append("<value type=\"string\" key=\"description\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDescription()) + "</value>\n");
            }

            if (getElementLayoutClass() != null) {
                xml.append("<value type=\"string\" key=\"elementLayoutClass\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getElementLayoutClass()) + "</value>\n");
            }

            if (getConnectionLayoutClass() != null) {
                xml.append("<value type=\"string\" key=\"connectionLayoutClass\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getConnectionLayoutClass()) + "</value>\n");
            }

            if (getElements() != null) {
                getElements().getGrtXml(xml, " key=\"elements\"");
            }

            if (getLayers() != null) {
                getLayers().getGrtXml(xml, " key=\"layers\"");
            }

            if (getSelection() != null) {
                getSelection().getGrtXml(xml, " key=\"selection\"");
            }

            if (getRootLayer() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"rootLayer\">"
                        + getRootLayerById() + "</value>\n");
            }

        return xml;
    }
}
